from sparrow.path import rel_to_abs
import os


def test_rel_to_abs():
    assert os.path.exists(rel_to_abs('test_path.py'))
    assert os.path.exists(rel_to_abs('../sparrow'))
    assert os.path.exists(rel_to_abs('../sparrow/__init__.py'))



import logging
import numpy as np
from sparrow.version_ops import VersionControl
from sparrow.string.color_string import *
from sparrow.core import *
from sparrow.decorators import *
from sparrow.time import *
import time


# vc = VersionControl("sparrow-tool")
# vc.update_version(1)


# @repeat(10)
@benchmark
@optional_debug
@broadcast
def function(n):
    s = n
    time.sleep(0.1)
    return s


if __name__ == "__main__":
    print(rgb_string("hello rgb string", YELLOW))
    print(rgb_string("hello rgb string", GREEN))
    print(rgb_string("hello rgb string", [1., 1., 1.]))
    color = np.array([0.5, 0.5, 1.])
    print(rgb_string("hello rgb string", color))
    print(rgb_string("hello rgb string", [23, 233, 233]))
    print(rgb_string("hello rgb string", np.array([23, 233, 233])))
    # print(function(300, 23, 432, debug=True))
    # print(function(200))
    # logging.basicConfig(level=logging.DEBUG, format='%(asctime)s - %(name)s - %(levelname)s - %(message)s')
    # # 声明了一个 Logger 对象
    # logger = logging.getLogger(__name__)
    #
    # logger.info("Start print log")
    # logger.debug("Do something")
    # logger.warning("Something maybe fail.")
    # logger.info("Finish")
    # print(inspect.signature(function))
    # bj = Beijing()
    # print(bj.now)



import numpy as np
from einops import rearrange, reduce, asnumpy, parse_shape
from sparrow.transform import repeat


def test_array():
    c, w, h = 3, 100, 50
    a = np.arange(c * w * h, dtype='float').reshape((c, w, h))
    assert a.shape == (c, w, h)
    assert rearrange(a, 'c w h -> w h c').shape == (w, h, c)

    a = reduce(a, 'c w h -> w h', 'mean')
    assert a.shape == (w, h)


def test_repeat():
    a1 = np.random.randn(10)
    assert repeat(a1, 3, 0).shape == (3, 10)
    assert repeat(a1, 3, -1).shape == (10, 3)

    a2 = np.random.randn(20, 30)
    assert repeat(a2, 3, 0).shape == (3, 20, 30)
    assert repeat(a2, 3, -1).shape == (20, 30, 3)

    a3 = np.random.randn(20, 30, 3)
    assert repeat(a3, 10, 0).shape == (10, 20, 30, 3)
    assert repeat(a3, 10, -1).shape == (20, 30, 3, 10)
    assert repeat(a3, 10, 1).shape == (20, 10, 30, 3,)



#!/usr/bin/env python

from __future__ import print_function
from setuptools import setup

pkgname = "sparrow-tool"
pkgdir = "sparrow"

setup(
    setup_requires=['pbr>=1.9', 'setuptools>=50.3.2', 'setuptools-declarative-requirements'],
    pbr=True,
    package_data={
        pkgdir: [
            '*.yaml', '*.yml',
        ],
    },
)
